/*************************************************************************
* Copyright (C) 2016 Intel Corporation
*
* Licensed under the Apache License,  Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* 	http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law  or agreed  to  in  writing,  software
* distributed under  the License  is  distributed  on  an  "AS IS"  BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the  specific  language  governing  permissions  and
* limitations under the License.
*************************************************************************/

/*
//
//  Purpose:
//     Cryptography Primitive.
//     Security Hash Standard
//     Generalized Functionality
//
//  Contents:
//        ippsHashGetSize_rmf()
//        ippsHashGetSizeOptimal_rmf()
//
*/

#include "owndefs.h"
#include "owncp.h"
#include "hash/pcphash_rmf.h"
#include "pcptool.h"

/*F*
//    Name: ippsHashGetSize_rmf
//
// Purpose: Returns size (bytes) of hash state, universal for supported hash methods.
//
// Returns:                Reason:
//    ippStsNullPtrErr        pSize == NULL
//    ippStsNoErr             no errors
//
// Parameters:
//    pSize       pointer to state size
//
*F*/
IPPFUN(IppStatus, ippsHashGetSize_rmf, (int* pSize))
{
    /* test pointers */
    IPP_BAD_PTR1_RET(pSize);
    *pSize = MAX_HASH_RMF_CONTEXT_SIZE;

    return ippStsNoErr;
}

/*F*
//    Name: ippsHashGetSizeOptimal_rmf
//
// Purpose: Returns size (bytes) of hash state depending on method.
//
// Returns:                Reason:
//    ippStsNullPtrErr        pSize == NULL OR pMethod == NULL
//    ippStsNoErr             no errors
//
// Parameters:
//    pSize       pointer to state size
//    pMethod     pointer to hash method state
//
*F*/
IPPFUN(IppStatus, ippsHashGetSizeOptimal_rmf, (int* pSize, const IppsHashMethod* pMethod))
{
    /* test pointers */
    IPP_BAD_PTR2_RET(pSize, pMethod);

    *pSize = (int)((Ipp8u)(sizeof(IppsHashState_rmf)) + pMethod->msgBlkSize + pMethod->stateLen);

    return ippStsNoErr;
}
